@@ -127,11 +127,12 @@ def make_node(
 
     # Generate input OPs for TensorFlow subgraphs
     # For inference testing on OP stand-alone
-    tf_partial_model_inputs: List[tf.keras.Input] = \
-        make_tf_partial_model_inputs(
-            input_tensors=[input_tensor]
-        )
-    tf_partial_model_outputs = None
+    if kwargs['acc_check']:
+        tf_partial_model_inputs: List[tf.keras.Input] = \
+            make_tf_partial_model_inputs(
+                input_tensors=[input_tensor]
+            )
+        tf_partial_model_outputs = None
 
     # Generation of TF OP
     # https://github.com/onnx/onnx/blob/main/docs/Changelog.md#unsqueeze-13
@@ -158,7 +159,7 @@ def make_node(
         tf_layers_dict[graph_node_output.name]['tf_node'] = \
             tf.identity(input=input_tensor)
         ### Partial model
-        if tf_partial_model_inputs is not None:
+        if kwargs['acc_check'] and tf_partial_model_inputs is not None:
             tf_partial_model_outputs = \
                 [
                     tf.identity(
@@ -172,7 +173,7 @@ def make_node(
         tf_layers_dict[graph_node_output.name]['tf_node'] = \
             tf.identity(input=input_tensor)
         ### Partial model
-        if tf_partial_model_inputs is not None:
+        if kwargs['acc_check'] and tf_partial_model_inputs is not None:
             tf_partial_model_outputs = \
                 [
                     tf.identity(
@@ -191,7 +192,7 @@ def make_node(
                 name=graph_node.name,
             )
         ### Partial model
-        if tf_partial_model_inputs is not None:
+        if kwargs['acc_check'] and tf_partial_model_inputs is not None:
             tf_partial_model_outputs = \
                 [
                     tf.expand_dims(
@@ -208,7 +209,7 @@ def make_node(
                 name=graph_node.name,
             )
         ### Partial model
-        if tf_partial_model_inputs is not None:
+        if kwargs['acc_check'] and tf_partial_model_inputs is not None:
             tf_partial_model_outputs = \
                 [
                     tf.reshape(
@@ -218,7 +219,7 @@ def make_node(
                 ]
 
     ### Partial model
-    if tf_partial_model_inputs is not None:
+    if kwargs['acc_check'] and tf_partial_model_inputs is not None:
         tf_partial_model = tf.keras.Model(
             inputs=tf_partial_model_inputs,
             outputs=tf_partial_model_outputs,
